@@ -33,24 +33,14 @@
 #include <goffice/utils/go-marshalers.h>
 
 #include <goffice/utils/go-color.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtkdrawingarea.h>
-#include <gtk/gtkimagemenuitem.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtktooltips.h>
-#include <gtk/gtkcolorseldialog.h>
+#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdkcolor.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gsf/gsf-impl-utils.h>
 
 #include <string.h>
 
-typedef struct _ColorNamePair ColorNamePair;
 struct _GOColorPalette {
 	GtkVBox	base;
 
@@ -65,7 +55,7 @@ struct _GOColorPalette {
 	GtkTooltips *tip;
 
 	/* The table with our default color names */
-	ColorNamePair const *default_set;
+	GONamedColor const *default_set;
 };
 
 typedef struct {
@@ -86,12 +76,7 @@ enum {
 	LAST_SIGNAL
 };
 
-struct _ColorNamePair {
-	GOColor	color;
-	char const *name;	/* english name - eg. "white" */
-};
-
-static ColorNamePair const default_color_set [] = {
+GONamedColor const default_color_set [] = {
 	{ RGBA_TO_UINT (0x00, 0x00, 0x00, 0xff), N_("black")},
 	{ RGBA_TO_UINT (0x99, 0x33, 0x00, 0xff), N_("light brown")},
 	{ RGBA_TO_UINT (0x33, 0x33, 0x00, 0xff), N_("brown gold")},
@@ -258,7 +243,7 @@ GSF_CLASS (GOColorPalette, go_color_palette,
  * Utility function
  */
 static gboolean
-color_in_palette (ColorNamePair const *set, GOColor color)
+color_in_palette (GONamedColor const *set, GOColor color)
 {
 	int i;
 
@@ -326,7 +311,7 @@ swatch_activated (GOColorPalette *pal, GtkBin *button)
 static gboolean
 cb_swatch_release_event (GtkBin *button, GdkEventButton *event, GOColorPalette *pal)
 {
-#warning TODO do I want to check for which button ?
+/* FIXME FIXME FIXME TODO do I want to check for which button ? */
 	swatch_activated (pal, button);
 	return TRUE;
 }
@@ -350,7 +335,7 @@ cb_swatch_key_press (GtkBin *button, GdkEventKey *event, GOColorPalette *pal)
  */
 static GtkWidget *
 go_color_palette_button_new (GOColorPalette *pal, GtkTable* table, GtkTooltips *tip,
-			  ColorNamePair const * color_name, gint col, gint row)
+			     GONamedColor const * color_name, gint col, gint row)
 {
         GtkWidget *button, *swatch, *box;
 	GdkColor   gdk;
@@ -436,7 +421,7 @@ static GtkWidget *
 go_color_palette_setup (GOColorPalette *pal,
 		     char const *no_color_label,
 		     int cols, int rows,
-		     ColorNamePair const *color_names)
+		     GONamedColor const *color_names)
 {
 	GtkWidget	*w, *table;
 	GtkTooltips	*tip;
@@ -454,8 +439,12 @@ go_color_palette_setup (GOColorPalette *pal,
 	}
 
 	pal->tip = tip = gtk_tooltips_new ();
+#if GLIB_CHECK_VERSION(2,10,0) && GTK_CHECK_VERSION(2,8,14)
+	g_object_ref_sink (pal->tip);
+#else
 	g_object_ref (pal->tip);
 	gtk_object_sink (GTK_OBJECT (pal->tip));
+#endif
 
 	for (row = 0; row < rows; row++)
 		for (col = 0; col < cols; col++) {
@@ -471,7 +460,7 @@ custom_colors :
 	if (col > 0)
 		row++;
 	for (col = 0; col < cols && col < GO_COLOR_GROUP_HISTORY_SIZE; col++) {
-		ColorNamePair color_name = { 0, N_("custom") };
+		GONamedColor color_name = { 0, N_("custom") };
 		color_name.color = pal->group->history [col];
 		pal->swatches [col] = go_color_palette_button_new (pal,
 			GTK_TABLE (table), GTK_TOOLTIPS (tip),
@@ -529,7 +518,7 @@ go_color_palette_new (char const *no_color_label,
 	GOColorPalette *pal;
 	int const cols = 8;
 	int const rows = 6;
-	ColorNamePair const *color_names = default_color_set;
+	GONamedColor const *color_names = default_color_set;
 
 	pal = g_object_new (GO_COLOR_PALETTE_TYPE, NULL);
 
@@ -668,7 +657,7 @@ go_color_palette_make_menu (char const *no_color_label,
 	int cols = 8;
 	int rows = 6;
 	int col, row, pos, table_row = 0;
-	ColorNamePair const *color_names = default_color_set;
+	GONamedColor const *color_names = default_color_set;
         GtkWidget *w, *submenu;
 
 	submenu = g_object_new (go_menu_color_get_type (), NULL);
